@@ -1,7 +1,8 @@
-import requests
 import json
-from loguru import logger
+import requests
 
+from loguru import logger
+from rsack.exceptions import DeviceIDError
 class Client:
 
     def __init__(self):
@@ -13,6 +14,8 @@ class Client:
             "Referer": "app.genie.co.kr"
         })
 
+        self.session.mount('https://', requests.adapters.HTTPAdapter(max_retries=3))
+        
     def make_call(self, sub, epoint, data):
         """
         :param sub: Url Prefix
@@ -107,16 +110,19 @@ class Client:
             q = '24bit'
         data = {
             "bitrate": q,
+            "sign": "Y",
+            "mts": "Y",
             "dcd": self.dev_id,
             "stk": self.stm_token,
             "svc": "IV",
             "unm": self.usr_num,
             "uxtk": self.usr_token,
-            "xgnm": id
+            "xgnm": id,
+            "apvn": 40807
         }
         r = self.make_call("stm", "player/j_StmInfo.json", data)
         if r['Result']['RetCode'] == "A00003":
-            logger.critical("Device ID has changed since last stream resulting in playback error.")
+            raise DeviceIDError()
         if r['Result']['RetCode'] != "0":
             logger.critical("Failed to retrieve metadata")
         if r['Result']['RetCode'] == "S00001":
